<?php

/*
 * Plugin Name: BigMailChimp
 * Plugin URI: http://bigemployee.com/projects/big-mailchimp-wordpress-plugin/
 * Description: Display your mail chimp capture form on your wordpress site.
 * Author: Arian Khosravi, Norik Davtian
 * Author URI: http://bigemployee.com
 * Version: 1.1
 * License: GPL3
 * License URI: http://www.gnu.org/licenses/gpl.html
 */
global $BigMailChimp_DB_version;
$BigMailChimp_DB_version = "1.0";

class BigMailChimp {

    function BigMailChimp() {
        define('BIGMAILCHIMP_PATH', plugin_dir_path(__FILE__));
        define('BIGMAILCHIMP_URL', plugins_url('', __FILE__) . '/');
        add_action('init', array(&$this, 'init_BigMailChimp_Scripts'));
        add_action('widgets_init', array(&$this, 'init_BigMailChimp_Widgets'));
        add_action('admin_enqueue_scripts', array(&$this, 'init_BigMailChimp_admin_head'));
        add_action('admin_menu', array(&$this, 'init_BigMailChimp_menu'));
        add_action('load-post.php', array(&$this, 'init_BigMailChimp_MetaBox'));
        add_action('load-post-new.php', array(&$this, 'init_BigMailChimp_MetaBox'));
        add_action('wp_footer', array(&$this, 'print_BigMailChimp_Frontend_Scripts'));
        add_action('wp_print_styles', array(&$this, 'print_BigMailChimp_Frontend_Styles'));
        add_shortcode('BigMailChimp', array(&$this, 'init_BigMailChimp_ShortCode'));
    }

    function init_BigMailChimp_menu() {
        $menu_page = add_menu_page('Big MailChimp', 'Big MailChimp', 'administrator', "big-mailchimp", array(&$this, 'init_bigMailChimp'), plugins_url('views/images/bigmc20.png', __FILE__));
        add_action('admin_print_styles-' . $menu_page, array(&$this, 'print_BigMailChimp_admin_styles'));
        add_action('load-' . $menu_page, array(&$this, 'init_BigMailChimp_Help_Tab'));
    }

    function init_bigMailChimp() {
        include_once 'library/Loader.php';
        Loader::init();
        include 'controllers/bigMailChimpController.php';
    }

    function init_BigMailChimp_Scripts() {
        wp_register_style('bigMailChimp-adimn-style', plugins_url('views/css/admin.css', __FILE__), false, '1.0', 'all');
        wp_register_style('bigMailChimp-style', plugins_url('views/css/bigMailChimp.css', __FILE__), false, '1.0', 'all');

        wp_register_script('bigMC-shortcode-script', plugins_url('views/js/bigMC-shortCode.js', __FILE__), array('jquery'), '1.0', true);
        wp_register_script('BigMailChimp-submit-script', plugins_url('views/js/BigMailChimp.js', __FILE__), array('jquery'), '1.0', true);
    }

    function print_BigMailChimp_admin_styles() {
        wp_enqueue_style('bigMailChimp-adimn-style');
    }

    function init_BigMailChimp_admin_head($hook) {
        if ('post.php' == $hook || 'post-new.php' == $hook) {
            wp_enqueue_script('jquery');
            wp_enqueue_script('bigMC-shortcode-script');
        }
    }

    function print_BigMailChimp_Frontend_Styles() {
        wp_enqueue_style('bigMailChimp-style');
    }

    function print_BigMailChimp_Frontend_Scripts() {
        wp_enqueue_script('jquery');
        wp_enqueue_script('BigMailChimp-submit-script');
    }

    function init_BigMailChimp_Widgets() {
        include_once 'library/Loader.php';
        Loader::init();
        register_widget("MCFormWidget");
    }

    function init_BigMailChimp_ShortCode($atts, $content = NULL) {
        include_once 'library/Loader.php';
        Loader::init();
        extract(shortcode_atts(array(
                    'list' => ''), $atts));
        $MCMapper = new MCListMapper();
        if ($MClist = $MCMapper->find($list, new MCList())) {
            $api = new MCAPI($MClist->getApi_key());
            $list_prop = $api->lists(array('list_id' => $MClist->getList_id()));
            $form = new Forms_MCGenerated($list_prop['data'][0]['web_id'], BIGMAILCHIMP_URL . "includes/mc.php?id=" . $MClist->getId(), 'post', NULL,
                            array('apiKey' => $MClist->getApi_key(), 'listId' => $MClist->getList_id()));
            return $form->print_form();
        }
    }

    function init_BigMailChimp_Help_Tab() {
        $screen = get_current_screen();
        $screen->add_help_tab(array(
            'id' => 'bigMailChimp_overview',
            'title' => __('Overview'),
            'content' =>
            '<p>' . __('Display your mailchimp capture form on your wordpress site.') . '</p>'.
            '<p>' . __('Add your Mailchimp lists and display them on your site in content area or as a widget.') . '</p>'.
            '<p>' . __('For more information visit the <a href="http://bigemployee.com/projects/">plugins page</a>.') . '</p>'
            ));
        $screen->add_help_tab(array(
            'id' => 'bigMailChimp_add',
            'title' => __('Add New List'),
            'content' =>
            '<p>' . __('Press Add new and enter API Key/List ID to add a list') . '</p>' .
            '<p>' . __('To obtain your API Key visit <a href="http://admin.mailchimp.com/account/api">Mailchimp API Page</a>') . '</p>' .
            '<p>' . __('You can find the list id under Lists->Settings->List Settings and Unique ID after you log into <a href="http://mailchimp.com">mailchimp.com</a>') . '</p>'.
            '<p>' . __('For more information visit the <a href="http://bigemployee.com/projects/">plugins page</a>.') . '</p>'
            ));
        $screen->set_help_sidebar(
                '<p><strong>For more information:</strong></p>' .
                '<p><a href="http://www.bigemployee.com">www.bigemployee.com</a></p>');
    }

    function init_BigMailChimp_MetaBox() {
        include_once 'library/Loader.php';
        Loader::init();
        $screen = get_current_screen();
        $screen->add_help_tab(array(
            'id' => 'bigMailChimp_settings',
            'title' => __('Big Mailchimp Page'),
            'content' =>
            '<p>' . __('Simply select one of your Mailchimp lists from the BigMailChimp meta box and click insert into page.') . '</p>' .
            '<p>' . __('If BigMailChimp meta box is not available on this page you can enable it from the Screen Options drawer.') . '</p>' .
            '<p>' . __('For more information visit the <a href="http://bigemployee.com/projects/">plugins page</a>.') . '</p>'
        ));
        return new MCShortCodeGen();
    }

    function installBigMailChimp() {
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        global $wpdb;
        global $BigContact_DB_V;

        $lists_table = $wpdb->prefix . 'big_mailchimp_lists';
        add_option("BigMailChimp_DB_version", "1.0");

        $query = "DROP TABLE IF EXISTS `$lists_table`;

CREATE TABLE IF NOT EXISTS `$lists_table` (
`id` INT NOT NULL AUTO_INCREMENT,
`api_key` VARCHAR(255) NULL,
`list_id` VARCHAR(255) NULL,
PRIMARY KEY (`id`))";
        dbDelta($query);
    }

    function uninstallBigMailChimp() {
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        global $wpdb;
        $lists_table = $wpdb->prefix . 'big_mailchimp_lists';
        $wpdb->query("DROP TABLE " . $lists_table);
    }

}

register_activation_hook(__FILE__, array('BigMailChimp', 'installBigMailChimp'));
register_deactivation_hook(__FILE__, array('BigMailChimp', 'uninstallBigMailChimp'));
$mybackuper = &new BigMailChimp(); //instance of the plugin class